==> pymedphys_xlwings-0.10.0.tar.gz: pymedphys_xlwings-0.10.0/src/pymedphys_xlwings/xlwings/__init__.py <==
# Copyright (C) 2019 Cancer Care Associates

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version (the "AGPL-3.0+").

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License and the additional terms for more
# details.

# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

# ADDITIONAL TERMS are also included as allowed by Section 7 of the GNU
# Affero General Public License. These additional terms are Sections 1, 5,
# 6, 7, 8, and 9 from the Apache License, Version 2.0 (the "Apache-2.0")
# where all references to the definition "License" are instead defined to
# mean the AGPL-3.0+.

# You should have received a copy of the Apache-2.0 along with this
# program. If not, see <http://www.apache.org/licenses/LICENSE-2.0>.


"""Expose a range of pymedphys, scipy, and numpy functions for use within
Excel via xlwings udf functionality.
"""

from .dicom import (
    depth_dose, inplane_profile, crossplane_profile, arbitrary_profile)
from .interpolate import linear_interpolation, nd_linear_interpolation
from .mephysto import mephysto
from .numpy import npravel, nprepeat
from .path import current_directory

==> pymedphys_xlwings-0.11.0.tar.gz: pymedphys_xlwings-0.11.0/src/pymedphys_xlwings/xlwings/__init__.py <==
# Copyright (C) 2019 Cancer Care Associates

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version (the "AGPL-3.0+").

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License and the additional terms for more
# details.

# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

# ADDITIONAL TERMS are also included as allowed by Section 7 of the GNU
# Affero General Public License. These additional terms are Sections 1, 5,
# 6, 7, 8, and 9 from the Apache License, Version 2.0 (the "Apache-2.0")
# where all references to the definition "License" are instead defined to
# mean the AGPL-3.0+.

# You should have received a copy of the Apache-2.0 along with this
# program. If not, see <http://www.apache.org/licenses/LICENSE-2.0>.


"""Expose a range of pymedphys, scipy, and numpy functions for use within
Excel via xlwings udf functionality.
"""

from .dicom import depth_dose, inplane_profile, crossplane_profile, arbitrary_profile
from .interpolate import linear_interpolation, nd_linear_interpolation
from .mephysto import mephysto
from .numpy import npravel, nprepeat
from .path import current_directory
